ConscentMethods class

Constructors

ConscentMethods()

Properties

contentAccessModel ↔ ContentAccessModel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loginId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

geSubscriptionAccess() → Future<SubscriptionAccess?>
getContentAccess() → Future<ContentAccessModel?>
getOSVersion() → Future<void>
getPaywallConfig() → Future<PaywallConfig>
getPstssForSubs() → Future<SubscriptionAccess?>
getSessionIDForSubs(String loginId) → Future<SubscriptionAccess?>
getUser() → Future<GetUserDetail?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDebugPrint(String message) → void
onPluginError(String error) → void
onTapFun() → void
pageViewDisposeEvent(double heights, double onScollDepth) → Future<void>
pageViewEvent(double heights, double onScollDepth) → Future<void>
paywallClickEvent(String clickAction) → Future<void>
paywallViewEvent() → Future<void>
prepareAutoLoginUrl(List<String> append) → Future<String>
prepareLoginChallenge(List<String> append) → Future<String>
toString() → String
A string representation of this object.
inherited
userLogOut() → Future<String?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited