Constants class

Constructors

Constants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

accessType ↔ String
getter/setter pair
conscentBalance ↔ String?
getter/setter pair
contentDetails2 ↔ ContentDetails2?
getter/setter pair
contentPrice ↔ String
getter/setter pair
couponCode ↔ String?
getter/setter pair
currencySymbol ↔ String
getter/setter pair
freeAccess ↔ bool?
getter/setter pair
idleTimeSpent ↔ int
getter/setter pair
logIn ↔ bool
getter/setter pair
mobileModel ↔ String?
getter/setter pair
numOfCta ↔ int
getter/setter pair
osName ↔ String?
getter/setter pair
osVersion ↔ String?
getter/setter pair
passPrice ↔ String
getter/setter pair
paywallConfig ↔ PaywallConfig
getter/setter pair
sessionExists ↔ bool
getter/setter pair
subscriptionPrice ↔ String
getter/setter pair
totalIdleTimeSpent ↔ int
getter/setter pair
totalTime ↔ int
getter/setter pair
userAgent ↔ String?
getter/setter pair