CoreDb class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAnonId() → void
deleteLoginId() → void
deleteSessionId() → void
deleteSubsUrl() → void
deleteUserId() → void
deleteUserType() → void
getAnonId() → Future<String?>?
getLoginId() → Future<String?>?
getSessionId() → Future<String?>?
getSubsUrl() → Future<String?>?
getUserId() → Future<String?>?
getUserType() → Future<String?>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAnonId(String anonId) → void
setLoginId(String loginId) → void
setSessionId(String sessionId) → void
setSubsUrl(String subsUrl) → void
setUserId(String? userId) → void
setUserType(String userType) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

instance() → dynamic