PaywallCustomization class

Constructors

PaywallCustomization({required ButtonStyle buttonStyle, required String micropaymentDisplaytext, required String subscriptionText, required String subscriptionTitle, required String crossButtonClickUrl, required String brandLogoUrl})
PaywallCustomization.fromJson(Map<String, dynamic> json)
factory

Properties

brandLogoUrl ↔ String
getter/setter pair
buttonStyle ↔ ButtonStyle
getter/setter pair
crossButtonClickUrl ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
micropaymentDisplaytext ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionText ↔ String
getter/setter pair
subscriptionTitle ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited