Tier class

Constructors

Tier({required PriceOverrides priceOverrides, required String currency, required double basePrice, required List<Offer> offers, required String id, required double price, required int duration})
Tier.fromJson(Map<String, dynamic> json)
factory

Properties

basePrice ↔ double
getter/setter pair
currency ↔ String
getter/setter pair
duration ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
offers ↔ List<Offer>
getter/setter pair
price ↔ double
getter/setter pair
priceOverrides ↔ PriceOverrides
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited