Address class

Constructors

Address({String? apartment, String? area, String? pincode, String? landmark, String? city, String? state, String? country})
Address.fromJson(Map<String, dynamic> json)

Properties

apartment ↔ String?
getter/setter pair
area ↔ String?
getter/setter pair
city ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
landmark ↔ String?
getter/setter pair
pincode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited