PageViewMessageBody class

Constructors

PageViewMessageBody({String? anonId, String? userId, String? eventType, String? eventLocation, String? deviceType, String? pageType, String? osVersion, String? userType, int? scrollDepth, int? pageLength, String? userSourceData, String? clientId, int? idleTimeSpent, int? activeTimeSpent, int? totalTimeSpent, String? contentId, bool? adblocker, bool? premiumContent, bool? unlockedStatus, String? accessType, String? url, String? osName, String? browser, String? userAgent, String? mobileModel})
PageViewMessageBody.fromJson(Map<String, dynamic> json)

Properties

accessType ↔ String?
getter/setter pair
activeTimeSpent ↔ int?
getter/setter pair
adblocker ↔ bool?
getter/setter pair
anonId ↔ String?
getter/setter pair
browser ↔ String?
getter/setter pair
clientId ↔ String?
getter/setter pair
contentId ↔ String?
getter/setter pair
deviceType ↔ String?
getter/setter pair
eventLocation ↔ String?
getter/setter pair
eventType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idleTimeSpent ↔ int?
getter/setter pair
mobileModel ↔ String?
getter/setter pair
osName ↔ String?
getter/setter pair
osVersion ↔ String?
getter/setter pair
pageLength ↔ int?
getter/setter pair
pageType ↔ String?
getter/setter pair
premiumContent ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDepth ↔ int?
getter/setter pair
totalTimeSpent ↔ int?
getter/setter pair
unlockedStatus ↔ bool?
getter/setter pair
url ↔ String?
getter/setter pair
userAgent ↔ String?
getter/setter pair
userId ↔ String?
getter/setter pair
userSourceData ↔ String?
getter/setter pair
userType ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited