Data class

Constructors

Data({Configuration? configuration, String? state, bool? enable, String? sId, String? clientId, String? name, String? createdAt, String? updatedAt, int? iV})
Data.fromJson(Map<String, dynamic> json)

Properties

clientId ↔ String?
getter/setter pair
configuration ↔ Configuration?
getter/setter pair
createdAt ↔ String?
getter/setter pair
enable ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iV ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sId ↔ String?
getter/setter pair
state ↔ String?
getter/setter pair
updatedAt ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited