MainDiv class

Constructors

MainDiv({String? border, String? borderRadius, String? backgroundColor, int? borderWidthValue, String? borderWidth, int? radius, String? borderColor, String? borderStyle})
MainDiv.fromJson(Map<String, dynamic> json)

Properties

backgroundColor ↔ String?
getter/setter pair
border ↔ String?
getter/setter pair
borderColor ↔ String?
getter/setter pair
borderRadius ↔ String?
getter/setter pair
borderStyle ↔ String?
getter/setter pair
borderWidth ↔ String?
getter/setter pair
borderWidthValue ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
radius ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited