MessageBody class

Constructors

MessageBody({String? anonId, String? userId, String? clientId, String? contentId, String? deviceType, String? eventLocation, String? eventType, int? isCookieBlocked, String? mobileModel, int? numOfCta, String? osName, String? osVersion, String? paywallDisplayType, String? paywallId, String? paywallType, String? userAgent})
MessageBody.fromJson(Map<String, dynamic> json)

Properties

anonId ↔ String?
getter/setter pair
clientId ↔ String?
getter/setter pair
contentId ↔ String?
getter/setter pair
deviceType ↔ String?
getter/setter pair
eventLocation ↔ String?
getter/setter pair
eventType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCookieBlocked ↔ int?
getter/setter pair
mobileModel ↔ String?
getter/setter pair
numOfCta ↔ int?
getter/setter pair
osName ↔ String?
getter/setter pair
osVersion ↔ String?
getter/setter pair
paywallDisplayType ↔ String?
getter/setter pair
paywallId ↔ String?
getter/setter pair
paywallType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent ↔ String?
getter/setter pair
userId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited