Subscription class

Constructors

Subscription({String? tierId, bool? digital, bool? physical, bool? adFree, String? title, bool? renew, int? duration, String? durationText})
Subscription.fromJson(Map<String, dynamic> json)

Properties

adFree ↔ bool?
getter/setter pair
digital ↔ bool?
getter/setter pair
duration ↔ int?
getter/setter pair
durationText ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
physical ↔ bool?
getter/setter pair
renew ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tierId ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited