SubscriptionAccess class

Constructors

SubscriptionAccess({bool? subscriptionAlreadyPurchased, List<PurchasedSubscriptions>? purchasedSubscriptions, bool? freeTrialConsumed, bool? allowRenewal, bool? internalUser, Payload? payload, String? consumptionId, String? signature, bool? downloadExists})
SubscriptionAccess.fromJson(Map<String, dynamic> json)

Properties

allowRenewal ↔ bool?
getter/setter pair
consumptionId ↔ String?
getter/setter pair
downloadExists ↔ bool?
getter/setter pair
freeTrialConsumed ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalUser ↔ bool?
getter/setter pair
payload ↔ Payload?
getter/setter pair
purchasedSubscriptions ↔ List<PurchasedSubscriptions>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ String?
getter/setter pair
subscriptionAlreadyPurchased ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited