FlutterFlowRadioButton class

Inheritance

Constructors

FlutterFlowRadioButton({required List<String> options, required dynamic onChanged(String?)?, String initialValue = '', required double optionHeight, required TextStyle textStyle, TextStyle? selectedTextStyle, EdgeInsetsGeometry textPadding = EdgeInsets.zero, RadioButtonPosition buttonPosition = RadioButtonPosition.left, Axis direction = Axis.vertical, required Color radioButtonColor, Color? inactiveRadioButtonColor, bool toggleable = false, WrapAlignment horizontalAlignment = WrapAlignment.start, WrapCrossAlignment verticalAlignment = WrapCrossAlignment.start})
const

Properties

buttonPosition → RadioButtonPosition
final
direction → Axis
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalAlignment → WrapAlignment
final
inactiveRadioButtonColor → Color?
final
initialValue → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → dynamic Function(String?)?
final
optionHeight → double
final
options → List<String>
final
radioButtonColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedTextStyle → TextStyle?
final
textPadding → EdgeInsetsGeometry
final
textStyle → TextStyle
final
toggleable → bool
final
verticalAlignment → WrapCrossAlignment
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FlutterFlowRadioButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited